window.Gleam.initSearch([{"doc":"gleamy_structures","title":"gleamy_structures","content":"# gleamy_structures\n\n[![Package Version](https://img.shields.io/hexpm/v/gleamy_structures)](https://hex.pm/packages/gleamy_structures)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gleamy_structures/)\n\nData structures in pure Gleam.\n\n## Supported Structures\n\n### Priority Queue\n\n`gleamy/priority_queue`:\n\nThis priority queue is a wrapper around `gleamy/pairing_heap`, providing additional functionality. The priority is comparison based in ascending order (lowest value first).\n\nYou may use the pairing heap or other heap structures directly for much of the same functionality.\n\n```gleam\n// priotity queue example\nimport gleam/int\nimport gleamy/priority_queue as pq\n\npub fn main() {\n  let q = pq.from_list([2, 1, 3], int.compare)\n  let x = pq.peek(q)\n  // x = Ok(1)\n}\n```\n\n### Heap\n\nThese heaps are min-heaps, providing efficient access to the minimum value based on a given comparison function.\n\n`gleamy/pairing_heap`:\n\nThis is the recommended heap structure for most use cases. However, for some non-linear use cases the performance can degrade because of the amortized nature of this structure.\n\n`gleamy/leftist_heap`:\n\nThis heap structure has consistent performance across all use cases.\n\n```gleam\n// heap example\nimport gleam/int\nimport gleamy/pairing_heap as heap\n\npub fn main() {\n  let h =\n    heap.new(int.compare)\n    |&gt; heap.insert(2)\n    |&gt; heap.insert(1)\n    |&gt; heap.insert(3)\n  let x = heap.find_min(h)\n  // x = Ok(1)\n}\n```\n\n### Non-Empty List\n\n`gleamy/non_empty_list`:\n\nNon-Empty list is a list structure that always contains at least one item.\n\n### Map\n\nMaps are used for key-value lookups. Keys are compared with a user-provided comparison function.\n\n`gleamy/map`:\n\nThis is a wrapper around `red_black_tree_map` providing additional utility functions.\n\n`gleamy/red_black_tree_map`:\n\nA map based on a red-black balanced tree structure.\n\n### Set\n\nSets are used to store a collection of items. Items are compared with a user-provided comparison function to remove duplicate values.\n\n`gleamy/set`:\n\nThis is a wrapper around `red_black_tree_set` providing additional utility functions.\n\n`gleamy/red_black_tree_set`:\n\nA set based on a red-black balanced tree structure.\n\n### Planned Structures\n\n- graph\n- quadtree\n- array\n\n## Installation\n\nThis package can be added to your Gleam project:\n\n```sh\ngleam add gleamy_structures\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/gleamy_structures&gt;.\n\n## Contributions Welcome\n\nFeel free to make PRs, issues, or requests for new data structures and functions :)\n","url":"index.html"},{"doc":"gleamy/leftist_heap","title":"Heap","content":"pub opaque type Heap(a)\n\n\nSynonyms:\ngleamy/leftist_heap.Heap\ngleamy/leftist_heap Heap","url":"gleamy/leftist_heap.html#Heap"},{"doc":"gleamy/leftist_heap","title":"delete_min","content":"pub fn delete_min(heap: Heap(a)) -&gt; Result(#(a, Heap(a)), Nil)\n Removes and returns the minimum element from the heap, along with the\n new heap after deletion, if the heap is not empty.\n Time complexity: O(log n)\nSynonyms:\ngleamy/leftist_heap.delete_min\ngleamy/leftist_heap delete_min","url":"gleamy/leftist_heap.html#delete_min"},{"doc":"gleamy/leftist_heap","title":"find_min","content":"pub fn find_min(heap: Heap(a)) -&gt; Result(a, Nil)\n Returns the minimum element in the heap, if the heap is not empty.\n Time complexity: O(1)\nSynonyms:\ngleamy/leftist_heap.find_min\ngleamy/leftist_heap find_min","url":"gleamy/leftist_heap.html#find_min"},{"doc":"gleamy/leftist_heap","title":"insert","content":"pub fn insert(heap: Heap(a), item: a) -&gt; Heap(a)\n Inserts a new item into the heap, preserving the heap property.\n Time complexity: O(log n)\nSynonyms:\ngleamy/leftist_heap.insert\ngleamy/leftist_heap insert","url":"gleamy/leftist_heap.html#insert"},{"doc":"gleamy/leftist_heap","title":"merge","content":"pub fn merge(heap1: Heap(a), heap2: Heap(a)) -&gt; Heap(a)\n Merges two heaps into a new heap containing all elements from both heaps,\n preserving the heap property.\n The given heaps must have the same comparison function.\n Time complexity: O(log n)\nSynonyms:\ngleamy/leftist_heap.merge\ngleamy/leftist_heap merge","url":"gleamy/leftist_heap.html#merge"},{"doc":"gleamy/leftist_heap","title":"new","content":"pub fn new(compare: fn(a, a) -&gt; Order) -&gt; Heap(a)\n Creates a new empty heap with the provided comparison function.\nSynonyms:\ngleamy/leftist_heap.new\ngleamy/leftist_heap new","url":"gleamy/leftist_heap.html#new"},{"doc":"gleamy/leftist_heap","title":"gleamy/leftist_heap","content":" This module provides an implementation of the leftist heap data structure,\n a type of binary heap with efficient insert, find_min, and delete_min, and merge operations.","url":"gleamy/leftist_heap.html"},{"doc":"gleamy/red_black_tree_map","title":"Map","content":"pub opaque type Map(k, v)\n\n\nSynonyms:\ngleamy/red_black_tree_map.Map\ngleamy/red_black_tree_map Map","url":"gleamy/red_black_tree_map.html#Map"},{"doc":"gleamy/red_black_tree_map","title":"clear","content":"pub fn clear(tree: Map(a, b)) -&gt; Map(a, b)\n Removes all elements from the map, resulting in an empty map.\n Time complexity: O(1)\nSynonyms:\ngleamy/red_black_tree_map.clear\ngleamy/red_black_tree_map clear","url":"gleamy/red_black_tree_map.html#clear"},{"doc":"gleamy/red_black_tree_map","title":"delete","content":"pub fn delete(tree: Map(a, b), key: a) -&gt; Map(a, b)\n Removes a key-value pair from the map, if the key exists.\n Time complexity: O(log n)\nSynonyms:\ngleamy/red_black_tree_map.delete\ngleamy/red_black_tree_map delete","url":"gleamy/red_black_tree_map.html#delete"},{"doc":"gleamy/red_black_tree_map","title":"find","content":"pub fn find(tree: Map(a, b), key: a) -&gt; Result(b, Nil)\n Searches for a key in the map and returns the associated value if found.\n Time complexity: O(log n)\nSynonyms:\ngleamy/red_black_tree_map.find\ngleamy/red_black_tree_map find","url":"gleamy/red_black_tree_map.html#find"},{"doc":"gleamy/red_black_tree_map","title":"fold","content":"pub fn fold(tree: Map(a, b), acc: c, fun: fn(c, a, b) -&gt; c) -&gt; c\n Applies a function to every key-value pair in the map, accumulating\n the results with the provided initial accumulator value.\n Time complexity: O(n)\nSynonyms:\ngleamy/red_black_tree_map.fold\ngleamy/red_black_tree_map fold","url":"gleamy/red_black_tree_map.html#fold"},{"doc":"gleamy/red_black_tree_map","title":"foldr","content":"pub fn foldr(tree: Map(a, b), acc: c, fun: fn(c, a, b) -&gt; c) -&gt; c\n Applies a function to every key-value pair in the map, accumulating\n the results with the provided initial accumulator value, but in reverse order.\n Time complexity: O(n)\nSynonyms:\ngleamy/red_black_tree_map.foldr\ngleamy/red_black_tree_map foldr","url":"gleamy/red_black_tree_map.html#foldr"},{"doc":"gleamy/red_black_tree_map","title":"insert","content":"pub fn insert(tree: Map(a, b), key: a, value: b) -&gt; Map(a, b)\n Inserts a new key-value pair into the map.\n If the key already exists, its associated value is updated with the new value.\n Time complexity: O(log n)\nSynonyms:\ngleamy/red_black_tree_map.insert\ngleamy/red_black_tree_map insert","url":"gleamy/red_black_tree_map.html#insert"},{"doc":"gleamy/red_black_tree_map","title":"new","content":"pub fn new(compare: fn(a, a) -&gt; Order) -&gt; Map(a, b)\n Creates a new empty map with the provided comparison function for keys.\nSynonyms:\ngleamy/red_black_tree_map.new\ngleamy/red_black_tree_map new","url":"gleamy/red_black_tree_map.html#new"},{"doc":"gleamy/red_black_tree_map","title":"gleamy/red_black_tree_map","content":" This module provides an implementation of a red-black tree map, a self-balancing\n binary search tree data structure that maintains a balanced shape which ensures\n tree operations stay efficient.\n It associates keys with values, where each key is unique and ordered according\n to the comparison function.","url":"gleamy/red_black_tree_map.html"},{"doc":"gleamy/map","title":"Map","content":"pub type Map(k, v) =\n  tree.Map(k, v)\n The `Map(k, v)` type represents a map that associates keys of type `k`\n with values of type `v`.\n\nSynonyms:\ngleamy/map.Map\ngleamy/map Map","url":"gleamy/map.html#Map"},{"doc":"gleamy/map","title":"count","content":"pub fn count(map: Map(a, b)) -&gt; Int\n Returns the number of key-value pairs in the map.\n Time complexity: O(n)\nSynonyms:\ngleamy/map.count\ngleamy/map count","url":"gleamy/map.html#count"},{"doc":"gleamy/map","title":"delete","content":"pub fn delete(from map: Map(a, b), this key: a) -&gt; Map(a, b)\n Removes a key-value pair from the map, if the key exists.\nSynonyms:\ngleamy/map.delete\ngleamy/map delete","url":"gleamy/map.html#delete"},{"doc":"gleamy/map","title":"filter","content":"pub fn filter(\n  in map: Map(a, b),\n  for property: fn(a, b) -&gt; Bool,\n) -&gt; Map(a, b)\n Creates a new map containing only the key-value pairs from the original map\n that satisfy a given predicate function.\nSynonyms:\ngleamy/map.filter\ngleamy/map filter","url":"gleamy/map.html#filter"},{"doc":"gleamy/map","title":"fold","content":"pub fn fold(\n  over map: Map(a, b),\n  from initial: c,\n  with reducer: fn(c, a, b) -&gt; c,\n) -&gt; c\n Applies a function to every key-value pair in the map, accumulating\n the results with the provided initial accumulator value.\nSynonyms:\ngleamy/map.fold\ngleamy/map fold","url":"gleamy/map.html#fold"},{"doc":"gleamy/map","title":"from_list","content":"pub fn from_list(\n  members: List(#(a, b)),\n  compare: fn(a, a) -&gt; Order,\n) -&gt; Map(a, b)\n Creates a new map from a list of key-value pairs and a comparison function\n for keys.\nSynonyms:\ngleamy/map.from_list\ngleamy/map from_list","url":"gleamy/map.html#from_list"},{"doc":"gleamy/map","title":"get","content":"pub fn get(in map: Map(a, b), key key: a) -&gt; Result(b, Nil)\n Get the value associated with a given key in the map, if present.\nSynonyms:\ngleamy/map.get\ngleamy/map get","url":"gleamy/map.html#get"},{"doc":"gleamy/map","title":"has_key","content":"pub fn has_key(in map: Map(a, b), key key: a) -&gt; Bool\n Checks if the map contains a given key.\nSynonyms:\ngleamy/map.has_key\ngleamy/map has_key","url":"gleamy/map.html#has_key"},{"doc":"gleamy/map","title":"insert","content":"pub fn insert(\n  into map: Map(a, b),\n  key key: a,\n  value value: b,\n) -&gt; Map(a, b)\n Inserts a new key-value pair into the map, overwriting the value if the key\n already exists.\nSynonyms:\ngleamy/map.insert\ngleamy/map insert","url":"gleamy/map.html#insert"},{"doc":"gleamy/map","title":"merge","content":"pub fn merge(\n  intro dict: Map(a, b),\n  from new_entries: Map(a, b),\n) -&gt; Map(a, b)\n Merges two maps into a new map, keeping values from the second map\n if keys collide.\nSynonyms:\ngleamy/map.merge\ngleamy/map merge","url":"gleamy/map.html#merge"},{"doc":"gleamy/map","title":"new","content":"pub fn new(compare: fn(a, a) -&gt; Order) -&gt; Map(a, b)\n Creates a new empty map with the provided comparison function for keys.\nSynonyms:\ngleamy/map.new\ngleamy/map new","url":"gleamy/map.html#new"},{"doc":"gleamy/map","title":"take","content":"pub fn take(\n  from map: Map(a, b),\n  keeping desired: List(a),\n) -&gt; Map(a, b)\n Creates a new map containing only the key-value pairs from the original map\n where the keys are present in the given list of desired keys.\nSynonyms:\ngleamy/map.take\ngleamy/map take","url":"gleamy/map.html#take"},{"doc":"gleamy/map","title":"to_list","content":"pub fn to_list(map: Map(a, b)) -&gt; List(#(a, b))\n Converts the map to a list of key-value pairs.\nSynonyms:\ngleamy/map.to_list\ngleamy/map to_list","url":"gleamy/map.html#to_list"},{"doc":"gleamy/map","title":"gleamy/map","content":" This module provides an implementation of an ordered map data structure based on\n red-black trees. It associates keys of type `k` with values of type `v`.\n Keys are ordered by the comparison function.","url":"gleamy/map.html"},{"doc":"gleamy/non_empty_list","title":"NonEmptyList","content":"pub type NonEmptyList(a) {\n  End(first: a)\n  Next(first: a, rest: NonEmptyList(a))\n}\n The `NonEmptyList(a)` type represents a non-empty list of elements of type `a`.\n It has two cases: `End(first: a)` for a list with a single element, and\n `Next(first: a, rest: NonEmptyList(a))` for a list with multiple elements.\nEnd(first: a)\n\n\nNext(first: a, rest: NonEmptyList(a))\n\n\nSynonyms:\ngleamy/non_empty_list.NonEmptyList\ngleamy/non_empty_list NonEmptyList","url":"gleamy/non_empty_list.html#NonEmptyList"},{"doc":"gleamy/non_empty_list","title":"count","content":"pub fn count(list: NonEmptyList(a)) -&gt; Int\n Returns the count (number of elements) in the non-empty list.\n Time complexity: O(n)\nSynonyms:\ngleamy/non_empty_list.count\ngleamy/non_empty_list count","url":"gleamy/non_empty_list.html#count"},{"doc":"gleamy/non_empty_list","title":"filter","content":"pub fn filter(\n  list: NonEmptyList(a),\n  predicate: fn(a) -&gt; Bool,\n) -&gt; List(a)\n Filters the elements of the non-empty list based on a predicate function\n and returns a (potentially empty) list with the elements that satisfy the predicate.\nSynonyms:\ngleamy/non_empty_list.filter\ngleamy/non_empty_list filter","url":"gleamy/non_empty_list.html#filter"},{"doc":"gleamy/non_empty_list","title":"fold","content":"pub fn fold(\n  over list: NonEmptyList(a),\n  from initial: b,\n  with fun: fn(b, a) -&gt; b,\n) -&gt; b\n Applies a function to every element in the non-empty list, accumulating\n the results with the provided initial accumulator value.\nSynonyms:\ngleamy/non_empty_list.fold\ngleamy/non_empty_list fold","url":"gleamy/non_empty_list.html#fold"},{"doc":"gleamy/non_empty_list","title":"from_list","content":"pub fn from_list(list: List(a)) -&gt; Result(NonEmptyList(a), Nil)\n Tries to create a non-empty list from a regular (potentially empty) list.\n Returns an error if the input list is empty.\nSynonyms:\ngleamy/non_empty_list.from_list\ngleamy/non_empty_list from_list","url":"gleamy/non_empty_list.html#from_list"},{"doc":"gleamy/non_empty_list","title":"map","content":"pub fn map(\n  list: NonEmptyList(a),\n  transform: fn(a) -&gt; b,\n) -&gt; NonEmptyList(b)\n Applies a transformation function to every element in the non-empty list\n and returns a new non-empty list with the transformed elements.\nSynonyms:\ngleamy/non_empty_list.map\ngleamy/non_empty_list map","url":"gleamy/non_empty_list.html#map"},{"doc":"gleamy/non_empty_list","title":"reverse","content":"pub fn reverse(list: NonEmptyList(a)) -&gt; NonEmptyList(a)\n Reverses the order of elements in the non-empty list.\nSynonyms:\ngleamy/non_empty_list.reverse\ngleamy/non_empty_list reverse","url":"gleamy/non_empty_list.html#reverse"},{"doc":"gleamy/non_empty_list","title":"to_list","content":"pub fn to_list(list: NonEmptyList(a)) -&gt; List(a)\n Converts the non-empty list to a regular (potentially empty) list.\nSynonyms:\ngleamy/non_empty_list.to_list\ngleamy/non_empty_list to_list","url":"gleamy/non_empty_list.html#to_list"},{"doc":"gleamy/non_empty_list","title":"gleamy/non_empty_list","content":" This module provides a type and functions for working with non-empty lists,\n which are lists that are guaranteed to have at least one element.","url":"gleamy/non_empty_list.html"},{"doc":"gleamy/pairing_heap","title":"Heap","content":"pub opaque type Heap(a)\n\n\nSynonyms:\ngleamy/pairing_heap.Heap\ngleamy/pairing_heap Heap","url":"gleamy/pairing_heap.html#Heap"},{"doc":"gleamy/pairing_heap","title":"delete_min","content":"pub fn delete_min(heap: Heap(a)) -&gt; Result(#(a, Heap(a)), Nil)\n Removes and returns the minimum element from the heap along with the\n new heap after deletion, if the heap is not empty.\n Time complexity: O(log n) amortized\nSynonyms:\ngleamy/pairing_heap.delete_min\ngleamy/pairing_heap delete_min","url":"gleamy/pairing_heap.html#delete_min"},{"doc":"gleamy/pairing_heap","title":"find_min","content":"pub fn find_min(heap: Heap(a)) -&gt; Result(a, Nil)\n Returns the minimum element in the heap, if the heap is not empty.\n Time complexity: O(1)\nSynonyms:\ngleamy/pairing_heap.find_min\ngleamy/pairing_heap find_min","url":"gleamy/pairing_heap.html#find_min"},{"doc":"gleamy/pairing_heap","title":"insert","content":"pub fn insert(heap: Heap(a), key: a) -&gt; Heap(a)\n Inserts a new item into the heap, preserving the heap property.\n Time complexity: O(1)\nSynonyms:\ngleamy/pairing_heap.insert\ngleamy/pairing_heap insert","url":"gleamy/pairing_heap.html#insert"},{"doc":"gleamy/pairing_heap","title":"merge","content":"pub fn merge(heap1: Heap(a), heap2: Heap(a)) -&gt; Heap(a)\n Merges two heaps into a new heap containing all elements from both heaps,\n preserving the heap property.\n The given heaps must have the same comparison function.\n Time complexity: O(1)\nSynonyms:\ngleamy/pairing_heap.merge\ngleamy/pairing_heap merge","url":"gleamy/pairing_heap.html#merge"},{"doc":"gleamy/pairing_heap","title":"new","content":"pub fn new(compare: fn(a, a) -&gt; Order) -&gt; Heap(a)\n Creates a new empty heap with the provided comparison function.\nSynonyms:\ngleamy/pairing_heap.new\ngleamy/pairing_heap new","url":"gleamy/pairing_heap.html#new"},{"doc":"gleamy/pairing_heap","title":"gleamy/pairing_heap","content":" This module provides an implementation of the pairing heap data structure,\n a type of self-adjusting heap with efficient insert, find_min, and delete_min, and merge operations.","url":"gleamy/pairing_heap.html"},{"doc":"gleamy/priority_queue","title":"Queue","content":"pub type Queue(a) =\n  heap.Heap(a)\n The `Queue(a)` type represents a priority queue of elements of type `a`.\n\nSynonyms:\ngleamy/priority_queue.Queue\ngleamy/priority_queue Queue","url":"gleamy/priority_queue.html#Queue"},{"doc":"gleamy/priority_queue","title":"count","content":"pub fn count(queue: Heap(a)) -&gt; Int\n Returns the number of elements in the priority queue.\nSynonyms:\ngleamy/priority_queue.count\ngleamy/priority_queue count","url":"gleamy/priority_queue.html#count"},{"doc":"gleamy/priority_queue","title":"from_list","content":"pub fn from_list(\n  list: List(a),\n  compare: fn(a, a) -&gt; Order,\n) -&gt; Heap(a)\n Creates a new priority queue from a list of elements and a comparison function.\nSynonyms:\ngleamy/priority_queue.from_list\ngleamy/priority_queue from_list","url":"gleamy/priority_queue.html#from_list"},{"doc":"gleamy/priority_queue","title":"is_empty","content":"pub fn is_empty(queue: Heap(a)) -&gt; Bool\n Checks whether the priority queue is empty or not.\nSynonyms:\ngleamy/priority_queue.is_empty\ngleamy/priority_queue is_empty","url":"gleamy/priority_queue.html#is_empty"},{"doc":"gleamy/priority_queue","title":"new","content":"pub fn new(compare: fn(a, a) -&gt; Order) -&gt; Heap(a)\n Creates a new empty priority queue with the provided comparison function.\nSynonyms:\ngleamy/priority_queue.new\ngleamy/priority_queue new","url":"gleamy/priority_queue.html#new"},{"doc":"gleamy/priority_queue","title":"peek","content":"pub fn peek(from queue: Heap(a)) -&gt; Result(a, Nil)\n Returns the minimum element in the priority queue without removing it.\nSynonyms:\ngleamy/priority_queue.peek\ngleamy/priority_queue peek","url":"gleamy/priority_queue.html#peek"},{"doc":"gleamy/priority_queue","title":"pop","content":"pub fn pop(from queue: Heap(a)) -&gt; Result(#(a, Heap(a)), Nil)\n Removes and returns the minimum element from the priority queue,\n along with the new queue.\nSynonyms:\ngleamy/priority_queue.pop\ngleamy/priority_queue pop","url":"gleamy/priority_queue.html#pop"},{"doc":"gleamy/priority_queue","title":"push","content":"pub fn push(onto queue: Heap(a), this item: a) -&gt; Heap(a)\n Inserts a new element into the priority queue.\nSynonyms:\ngleamy/priority_queue.push\ngleamy/priority_queue push","url":"gleamy/priority_queue.html#push"},{"doc":"gleamy/priority_queue","title":"reorder","content":"pub fn reorder(\n  queue: Heap(a),\n  compare: fn(a, a) -&gt; Order,\n) -&gt; Heap(a)\n Rebuilds the priority queue with a new comparison function.\nSynonyms:\ngleamy/priority_queue.reorder\ngleamy/priority_queue reorder","url":"gleamy/priority_queue.html#reorder"},{"doc":"gleamy/priority_queue","title":"to_list","content":"pub fn to_list(queue: Heap(a)) -&gt; List(a)\n Converts the priority queue to a list, preserving the order of elements.\nSynonyms:\ngleamy/priority_queue.to_list\ngleamy/priority_queue to_list","url":"gleamy/priority_queue.html#to_list"},{"doc":"gleamy/priority_queue","title":"gleamy/priority_queue","content":" This module provides an implementation of a priority queue data structure\n based on the pairing heap. It allows efficient insertion, removal, and access\n to the minimum element in the queue.","url":"gleamy/priority_queue.html"},{"doc":"gleamy/red_black_tree_set","title":"Set","content":"pub opaque type Set(a)\n\n\nSynonyms:\ngleamy/red_black_tree_set.Set\ngleamy/red_black_tree_set Set","url":"gleamy/red_black_tree_set.html#Set"},{"doc":"gleamy/red_black_tree_set","title":"clear","content":"pub fn clear(tree: Set(a)) -&gt; Set(a)\n Removes all elements from the set, resulting in an empty set.\n Time complexity: O(1)\nSynonyms:\ngleamy/red_black_tree_set.clear\ngleamy/red_black_tree_set clear","url":"gleamy/red_black_tree_set.html#clear"},{"doc":"gleamy/red_black_tree_set","title":"delete","content":"pub fn delete(tree: Set(a), key: a) -&gt; Set(a)\n Removes an element from the set, if it exists.\n Time complexity: O(log n)\nSynonyms:\ngleamy/red_black_tree_set.delete\ngleamy/red_black_tree_set delete","url":"gleamy/red_black_tree_set.html#delete"},{"doc":"gleamy/red_black_tree_set","title":"find","content":"pub fn find(tree: Set(a), key: a) -&gt; Result(a, Nil)\n Searches for an element in the set and returns it if found.\n Time complexity: O(log n)\nSynonyms:\ngleamy/red_black_tree_set.find\ngleamy/red_black_tree_set find","url":"gleamy/red_black_tree_set.html#find"},{"doc":"gleamy/red_black_tree_set","title":"fold","content":"pub fn fold(tree: Set(a), acc: b, fun: fn(b, a) -&gt; b) -&gt; b\n Applies a function to every element in the set, accumulating\n the results with the provided initial accumulator value.\n Time complexity: O(n)\nSynonyms:\ngleamy/red_black_tree_set.fold\ngleamy/red_black_tree_set fold","url":"gleamy/red_black_tree_set.html#fold"},{"doc":"gleamy/red_black_tree_set","title":"foldr","content":"pub fn foldr(tree: Set(a), acc: b, fun: fn(b, a) -&gt; b) -&gt; b\n Applies a function to every element in set, accumulating the results with\n the provided initial accumulator value, but in reverse order.\n Time complexity: O(n)\nSynonyms:\ngleamy/red_black_tree_set.foldr\ngleamy/red_black_tree_set foldr","url":"gleamy/red_black_tree_set.html#foldr"},{"doc":"gleamy/red_black_tree_set","title":"insert","content":"pub fn insert(tree: Set(a), key: a) -&gt; Set(a)\n Inserts a new element into the set, preserving the set property (no duplicates).\n Time complexity: O(log n)\nSynonyms:\ngleamy/red_black_tree_set.insert\ngleamy/red_black_tree_set insert","url":"gleamy/red_black_tree_set.html#insert"},{"doc":"gleamy/red_black_tree_set","title":"new","content":"pub fn new(compare: fn(a, a) -&gt; Order) -&gt; Set(a)\n Creates a new empty set with the provided comparison function.\nSynonyms:\ngleamy/red_black_tree_set.new\ngleamy/red_black_tree_set new","url":"gleamy/red_black_tree_set.html#new"},{"doc":"gleamy/red_black_tree_set","title":"gleamy/red_black_tree_set","content":" This module provides an implementation of a red-black tree set, a self-balancing\n binary search tree data structure that maintains a balanced shape which ensures\n tree operations stay efficient.\n This is an ordered set implementation, meaning the tree will contains values that\n are unique and ordered according to the comparison function.","url":"gleamy/red_black_tree_set.html"},{"doc":"gleamy/set","title":"Set","content":"pub type Set(a) =\n  tree.Set(a)\n The `Set(a)` type represents a set of elements of type `a`. \n\nSynonyms:\ngleamy/set.Set\ngleamy/set Set","url":"gleamy/set.html#Set"},{"doc":"gleamy/set","title":"contains","content":"pub fn contains(in set: Set(a), this member: a) -&gt; Bool\n Checks if the set contains a given element.\nSynonyms:\ngleamy/set.contains\ngleamy/set contains","url":"gleamy/set.html#contains"},{"doc":"gleamy/set","title":"count","content":"pub fn count(set: Set(a)) -&gt; Int\n Returns the number of elements in the set.\n Time complexity: O(n)\nSynonyms:\ngleamy/set.count\ngleamy/set count","url":"gleamy/set.html#count"},{"doc":"gleamy/set","title":"delete","content":"pub fn delete(from set: Set(a), this member: a) -&gt; Set(a)\n Removes an element from the set, if it exists.\nSynonyms:\ngleamy/set.delete\ngleamy/set delete","url":"gleamy/set.html#delete"},{"doc":"gleamy/set","title":"difference","content":"pub fn difference(\n  from set: Set(a),\n  remove removal: Set(a),\n) -&gt; Set(a)\n Creates a new set containing the elements of the first set except for elements\n that are also in the second set.\nSynonyms:\ngleamy/set.difference\ngleamy/set difference","url":"gleamy/set.html#difference"},{"doc":"gleamy/set","title":"filter","content":"pub fn filter(\n  in set: Set(a),\n  for property: fn(a) -&gt; Bool,\n) -&gt; Set(a)\n Creates a new set containing only the elements from the original set\n that satisfy a given predicate function.\nSynonyms:\ngleamy/set.filter\ngleamy/set filter","url":"gleamy/set.html#filter"},{"doc":"gleamy/set","title":"fold","content":"pub fn fold(\n  over set: Set(a),\n  from initial: b,\n  with reducer: fn(b, a) -&gt; b,\n) -&gt; b\n Applies a function to every element in the set, accumulating\n the results with the provided initial accumulator value.\nSynonyms:\ngleamy/set.fold\ngleamy/set fold","url":"gleamy/set.html#fold"},{"doc":"gleamy/set","title":"from_list","content":"pub fn from_list(\n  members: List(a),\n  compare: fn(a, a) -&gt; Order,\n) -&gt; Set(a)\n Creates a new set from a list of elements and a comparison function.\nSynonyms:\ngleamy/set.from_list\ngleamy/set from_list","url":"gleamy/set.html#from_list"},{"doc":"gleamy/set","title":"insert","content":"pub fn insert(into set: Set(a), this member: a) -&gt; Set(a)\n Inserts a new element into the set, if it is not already present.\nSynonyms:\ngleamy/set.insert\ngleamy/set insert","url":"gleamy/set.html#insert"},{"doc":"gleamy/set","title":"intersection","content":"pub fn intersection(\n  of first: Set(a),\n  and second: Set(a),\n) -&gt; Set(a)\n Creates a new set containing the intersection (common elements) of two sets.\nSynonyms:\ngleamy/set.intersection\ngleamy/set intersection","url":"gleamy/set.html#intersection"},{"doc":"gleamy/set","title":"new","content":"pub fn new(compare: fn(a, a) -&gt; Order) -&gt; Set(a)\n Creates a new empty set with the provided comparison function.\nSynonyms:\ngleamy/set.new\ngleamy/set new","url":"gleamy/set.html#new"},{"doc":"gleamy/set","title":"to_list","content":"pub fn to_list(set: Set(a)) -&gt; List(a)\n Converts the set to a list of its elements.\nSynonyms:\ngleamy/set.to_list\ngleamy/set to_list","url":"gleamy/set.html#to_list"},{"doc":"gleamy/set","title":"union","content":"pub fn union(of first: Set(a), and second: Set(a)) -&gt; Set(a)\n Creates a new set containing the union (all elements) of two sets.\nSynonyms:\ngleamy/set.union\ngleamy/set union","url":"gleamy/set.html#union"},{"doc":"gleamy/set","title":"gleamy/set","content":" This module provides an implementation of an ordered set data structure\n based on red-black trees.\n A set is a collection of unique values, ordered by the comparison function.","url":"gleamy/set.html"}]);